@@ -22,6 +22,10 @@ from selenium.webdriver.common.by import By
 from selenium.webdriver.support.ui import Select
 from selenium.webdriver.chrome.options import Options
 
+import logging
+logger = logging.getLogger("PyPDF2")
+logger.setLevel(logging.ERROR)
+
 pd.set_option("mode.chained_assignment", None)
 pd.set_option("display.notebook_repr_html", True)
 pd.set_option('display.expand_frame_repr', False) 
@@ -718,7 +722,7 @@ def archive(conf):
       if dif > 0 and conf.LOG:
          click.echo(f"Removed {dif} duplicate cases from queue.")
 
-   if conf.APPEND_ARCHIVE == True:
+   if conf.APPEND == True:
       if conf.LOG:
          click.echo(f"Appending archive to existing archive at output path...")
          outputs = append_archive(outputs, conf.OUTPUT_PATH, obj=True)
